-- DT Chat Mods
--[[ Add more font sizes to chat menu ]]--
CHAT_FONT_HEIGHTS = { [1] = 10, [2] = 11, [3] = 12, [4] = 13, [5] = 14, [6] = 15, [7] = 16, [8] = 17, [9] = 18, [10] = 19, [11] = 20 }

--[[ Add scroll to top or bottom if shift key pressed and mouse scroll up/down ]]--
FloatingChatFrame_OnMouseScroll = function(self, dir)
  if(dir > 0) then
    if(IsShiftKeyDown()) then
      self:ScrollToTop()
    else
      self:ScrollUp()
    end
  else
    if(IsShiftKeyDown()) then
      self:ScrollToBottom()
    else
      self:ScrollDown()
    end
  end
end

--[[ Url link pop up window to copy ]]--
function doColor(url)
    url = " |cff99FF33|Hurl:"..url.."|h["..url.."]|h|r "
    return url
end

function urlFilter(self, event, msg, author, ...)
    if strfind(msg, "(%a+)://(%S+)%s?") then
        return false, gsub(msg, "(%a+)://(%S+)%s?", doColor("%1://%2")), author, ...
    end
    if strfind(msg, "www%.([_A-Za-z0-9-]+)%.(%S+)%s?") then
        return false, gsub(msg, "www%.([_A-Za-z0-9-]+)%.(%S+)%s?", doColor("www.%1.%2")), author, ...
    end
    if strfind(msg, "([_A-Za-z0-9-%.]+)@([_A-Za-z0-9-]+)(%.+)([_A-Za-z0-9-%.]+)%s?") then
        return false, gsub(msg, "([_A-Za-z0-9-%.]+)@([_A-Za-z0-9-]+)(%.+)([_A-Za-z0-9-%.]+)%s?", doColor("%1@%2%3%4")), author, ...
    end
    if strfind(msg, "(%d%d?%d?)%.(%d%d?%d?)%.(%d%d?%d?)%.(%d%d?%d?):(%d%d?%d?%d?%d?)%s?") then
        return false, gsub(msg, "(%d%d?%d?)%.(%d%d?%d?)%.(%d%d?%d?)%.(%d%d?%d?):(%d%d?%d?%d?%d?)%s?", doColor("%1.%2.%3.%4:%5")), author, ...
    end
    if strfind(msg, "(%d%d?%d?)%.(%d%d?%d?)%.(%d%d?%d?)%.(%d%d?%d?)%s?") then
        return false, gsub(msg, "(%d%d?%d?)%.(%d%d?%d?)%.(%d%d?%d?)%.(%d%d?%d?)%s?", doColor("%1.%2.%3.%4")), author, ...
    end
    if strfind(msg, "[wWhH][wWtT][wWtT][\46pP]%S+[^%p%s]") then
        return false, gsub(msg, "[wWhH][wWtT][wWtT][\46pP]%S+[^%p%s]", doColor("%1")), author, ...
    end
end
StaticPopupDialogs["LINKME"] = {
    text = "Use \"ctrl+c\" to Copy URL",
    button2 = CANCEL,
    hasEditBox = true,
    hasWideEditBox = true,
    timeout = 0,
    exclusive = 1,
    hideOnEscape = 1,
    EditBoxOnEscapePressed = function(self) self:GetParent():Hide() end,
    whileDead = 1,
    maxLetters = 255,
}

local SetHyperlink = _G.ItemRefTooltip.SetHyperlink
function _G.ItemRefTooltip:SetHyperlink(link, ...)
    if link and (strsub(link, 1, 3) == "url") then
        local url = strsub(link, 5)
        local dialog = StaticPopup_Show("LINKME")
        local editboxa = _G[dialog:GetName().."EditBox"]

        editboxa:SetText(url)
        editboxa:SetFocus()
        editboxa:HighlightText()

        local button = _G[dialog:GetName().."Button2"]
        button:ClearAllPoints()
        button:SetPoint("CENTER", editboxa, "CENTER", 0, -30)

        return
     end

     SetHyperlink(self, link, ...)
end

ChatFrame_AddMessageEventFilter("CHAT_MSG_BATTLEGROUND_LEADER", urlFilter)
ChatFrame_AddMessageEventFilter("CHAT_MSG_BN_CONVERSATION", urlFilter)
ChatFrame_AddMessageEventFilter("CHAT_MSG_BN_WHISPER", urlFilter)
ChatFrame_AddMessageEventFilter("CHAT_MSG_PARTY_LEADER", urlFilter)
ChatFrame_AddMessageEventFilter("CHAT_MSG_RAID_LEADER", urlFilter)
ChatFrame_AddMessageEventFilter("CHAT_MSG_RAID_WARNING", urlFilter)

ChatFrame_AddMessageEventFilter("CHAT_MSG_GUILD", urlFilter)
ChatFrame_AddMessageEventFilter("CHAT_MSG_OFFICER", urlFilter)
ChatFrame_AddMessageEventFilter("CHAT_MSG_PARTY", urlFilter)
ChatFrame_AddMessageEventFilter("CHAT_MSG_RAID", urlFilter)
ChatFrame_AddMessageEventFilter("CHAT_MSG_BATTLEGROUND", urlFilter)
ChatFrame_AddMessageEventFilter("CHAT_MSG_WHISPER", urlFilter)
ChatFrame_AddMessageEventFilter("CHAT_MSG_SAY", urlFilter)
ChatFrame_AddMessageEventFilter("CHAT_MSG_YELL", urlFilter)
ChatFrame_AddMessageEventFilter("CHAT_MSG_CHANNEL", urlFilter)
--[[ Add alt click invite player -- alt click player in chat to invite to group ]]--
 hooksecurefunc("SetItemRef", function(link)
  if IsAltKeyDown() then
   local player = link:match("^player:([^:]+)")
   InviteToGroup(player)
   -- We use a secure hook to stay clean (avoid taint), but this means a whisper window will open, so we close it.
   ChatEdit_OnEscapePressed(ChatFrame1EditBox)
  end
 end)

--[[ Removes the need hold down [alt] key when moving left and right with cursor keys in the chat editbox.
     You will still need to hold down [alt] key to arrow up or down through chat history. ]]--
for chatwin=1,NUM_CHAT_WINDOWS do
 chatwin=_G["ChatFrame"..chatwin.."EditBox"]
 chatwin:SetAltArrowKeyMode(false)
end

--[[ Channel Replacement alias to shorten names ]]--
CHAT_SAY_GET = "[S] %s: "
CHAT_YELL_GET = "[Y] %s: "
CHAT_WHISPER_GET = "[F] %s: "
CHAT_WHISPER_INFORM_GET = "[T] %s: "

CHAT_FLAG_AFK = "[AFK] "
CHAT_FLAG_DND = "[DND] "
CHAT_FLAG_GM = "[GM] "

CHAT_MONSTER_PARTY_GET = CHAT_PARTY_GET
CHAT_MONSTER_SAY_GET = CHAT_SAY_GET
CHAT_MONSTER_WHISPER_GET = CHAT_WHISPER_GET
CHAT_MONSTER_YELL_GET = CHAT_YELL_GET

local gsub = gsub
local time = _G.time
local newAddMsg = {}
local rplc = {
  "[GEN]", --General
  "[T]",   --Trade
  "[WD]",  --WorldDefense
  "[LD]",  --LocalDefense
  "[LFG]", --LookingForGroup
  "[GR]",  --GuildRecruitment
  "[I]",   --Instance
  "[IL]",  --Instance Leader
  "[G]",   --Guild
  "[P]",   --Party
  "[PL]",  --Party Leader
  "[PL]",  --Party Leader (Guide)
  "[O]",   --Officer
  "[R]",   --Raid
  "[RL]",  --Raid Leader
  "[RW]",  --Raid Warning
  "[%1]",  --Custom Channels
}

local chn = {
  "%[%d0?%. General.-%]",
  "%[%d0?%. Trade.-%]",
  "%[%d0?%. WorldDefense%]",
  "%[%d0?%. LocalDefense.-%]",
  "%[%d0?%. LookingForGroup%]",
  "%[%d0?%. GuildRecruitment.-%]",
  gsub(CHAT_INSTANCE_CHAT_GET, ".*%[(.*)%].*", "%%[%1%%]"),
  gsub(CHAT_INSTANCE_CHAT_LEADER_GET, ".*%[(.*)%].*", "%%[%1%%]"),
  gsub(CHAT_GUILD_GET, ".*%[(.*)%].*", "%%[%1%%]"),
  gsub(CHAT_PARTY_GET, ".*%[(.*)%].*", "%%[%1%%]"),
  gsub(CHAT_PARTY_LEADER_GET, ".*%[(.*)%].*", "%%[%1%%]"),
  gsub(CHAT_PARTY_GUIDE_GET, ".*%[(.*)%].*", "%%[%1%%]"),
  gsub(CHAT_OFFICER_GET, ".*%[(.*)%].*", "%%[%1%%]"),
  gsub(CHAT_RAID_GET, ".*%[(.*)%].*", "%%[%1%%]"),
  gsub(CHAT_RAID_LEADER_GET, ".*%[(.*)%].*", "%%[%1%%]"),
  gsub(CHAT_RAID_WARNING_GET, ".*%[(.*)%].*", "%%[%1%%]"),
  "%[(%d0?)%. (.-)%]",   --Custom Channels
}
local AddMessage = function(frame, text, ...)
  for i = 1, 17 do
      text = gsub(text, chn[i], rplc[i])
  end
  --If Blizz timestamps is enabled, stamp anything it misses
  if CHAT_TIMESTAMP_FORMAT and not text:find("^|r") then
     text = BetterDate(CHAT_TIMESTAMP_FORMAT, time())..text
  end
  text = gsub(text, "%[(%d0?)%. .-%]", "[%1]") --custom channels
  return newAddMsg[frame:GetName()](frame, text, ...)
end
for i = 1, 10 do
    local fcl = _G[format("%s%d", "ChatFrame", i)]
    --skip combatlog and frames with no messages registered
    if i ~= 2 then -- skip combatlog
       newAddMsg[format("%s%d", "ChatFrame", i)] = fcl.AddMessage
       fcl.AddMessage = AddMessage
    end
end

--[[ Chat fade hide ]]--
 CHAT_FRAME_TAB_NORMAL_NOMOUSE_ALPHA = 0
 CHAT_FRAME_TAB_SELECTED_NOMOUSE_ALPHA = 0
 CHAT_FRAME_BUTTON_FRAME_MIN_ALPHA = 0
 for i=1, 10 do
  local tab = _G[format("%s%d%s", "ChatFrame", i, "Tab")]
  tab:SetAlpha(0)
  tab.noMouseAlpha = 0
 end

--[[ Disable tab flashing. ]]--
  FCF_FlashTab = function() end
  FCFTab_UpdateAlpha = function() end

--[[ Font outline ]]--
for i = 1, 10 do
  local cF = _G[format("%s%d", "ChatFrame", i)]
  local font, size = cF:GetFont()
  cF:SetFont(font, size, "OUTLINE")
end

--[[ Misc functions (Frame size/move,Arrow keys,editbox to the top). ]]--
for i = 1, NUM_CHAT_WINDOWS do
    local editBoxleft = _G[format("%s%d%s", "ChatFrame", i, "EditBoxLeft")]
    local editBoxright = _G[format("%s%d%s", "ChatFrame", i, "EditBoxRight")]
    local editBoxmid = _G[format("%s%d%s", "ChatFrame", i, "EditBoxMid")]
    editBoxleft:SetAlpha(1)
    editBoxright:SetAlpha(1)
    editBoxmid:SetAlpha(1)
end

 --Classic mode hides the editbox when not in use, IM mode fades it out
 --since we move the editbox above the chat tabs, we don't want it always showing
SetCVar("chatStyle", "classic")
for i = 1, 10 do
    local eb =  _G[format("%s%d%s", "ChatFrame", i, "EditBox")]
    local cfs = _G[format("%s%d", "ChatFrame", i)]
    --Allow resizing chatframes to whatever size you wish!
    cfs:SetMinResize(100,10)
    cfs:SetMaxResize(0,0)
    --Allow the chat frame to move to the end of the screen
    cfs:SetClampRectInsets(0,0,0,0)
    eb:SetAltArrowKeyMode(false)

    eb:ClearAllPoints()
    eb:SetPoint("BOTTOMLEFT",  cfs, "TOPLEFT",  -5, 0)
    eb:SetPoint("BOTTOMRIGHT", cfs, "TOPRIGHT", 5, 0)
    eb:Hide() --call this incase we're just changing to classic mode for the first time
end
--[[ Chat copy ]]--
local frame = CreateFrame("Frame", "wCopyFrame", UIParent)
frame:SetBackdrop({
  bgFile = [[Interface\DialogFrame\UI-DialogBox-Background]],
  edgeFile = [[Interface\DialogFrame\UI-DialogBox-Border]],
  edgeSize = 16, tileSize = 16, tile = true,
  insets = { left = 1, right = 1, top = 1, bottom = 1 }
})
frame:SetBackdropColor(0,0,0,1)
frame:SetWidth(650)
frame:SetHeight(500)
frame:SetPoint("CENTER", UIParent, "CENTER")
frame:Hide()
frame:SetFrameStrata("DIALOG")

local scrollArea = CreateFrame('ScrollFrame', "wCopyScroll", frame, 'UIPanelScrollFrameTemplate')
scrollArea:SetPoint("TOPLEFT", frame, "TOPLEFT", 8, -5)
scrollArea:SetPoint("BOTTOMRIGHT", frame, "BOTTOMRIGHT", -30, 5)

local group = scrollArea:CreateAnimationGroup()
local update = group:CreateAnimation()
group:SetScript("OnFinished", function() wCopyScroll:SetVerticalScroll((wCopyScroll:GetVerticalScrollRange()) or 0) end)
update:SetOrder(1)
update:SetDuration(0.25)
wCopyScroll.ScrollToBottom = group

local editBox = CreateFrame("EditBox", "wCopyBox", frame)
editBox:SetMultiLine(true)
editBox:SetMaxLetters(99999)
editBox:EnableMouse(true)
editBox:SetAutoFocus(false)
editBox:SetFontObject(ChatFontNormal)
editBox:SetWidth(620)
editBox:SetHeight(495)
editBox:SetScript("OnEscapePressed", function(f) f:GetParent():GetParent():Hide() f:SetText("") end)

scrollArea:SetScrollChild(editBox)

local close = CreateFrame('Button', "wCloseButton", frame, 'UIPanelCloseButton')
close:SetPoint("TOPRIGHT", frame, "TOPRIGHT", 0, 25)
local CopyChat = function(self, chatTab)
 local chatFrame = _G['ChatFrame' .. chatTab:GetID()]
 local numMessages = chatFrame:GetNumMessages()
 if numMessages >= 1 then
  local GetMessageInfo = chatFrame.GetMessageInfo
  local text = GetMessageInfo(chatFrame, 1)
  for index = 2, numMessages do
   text = text .. "\n" .. GetMessageInfo(chatFrame, index)
  end
  frame:Show()
  editBox:SetText(text)
 end
end
hooksecurefunc('FCF_Tab_OnClick', function(self)
 local info = UIDropDownMenu_CreateInfo()
 info.text = "Open Copy Chat Window"
 info.notCheckable = true
 info.func = CopyChat
 info.arg1 = self
 UIDropDownMenu_AddButton(info)
end)
--EOF
