-- DT TinyMainbarInfo
-- disable pvp talent alerts
function MainMenuMicroButton_AreAlertsEffectivelyEnabled()
    return false
end

local FORMAT_COORDS = "|TInterface\\CURSOR\\Directions.png:0|t %.1f, %.1f"
local FORMAT_NETSTATS = "%.2f KB/S"
local FORMAT_TIME_ONLINE = "%d:%02d:%02d"
local FORMAT_MEMORY_USAGE = "%.2f MB"
local FORMAT_FPS
local FORMAT_LAG = ""
local FORMAT_DURABILITY
local FORMAT_ILEVEL = "%d"
local FORMAT_ILEVEL_COLOR
local GUILD_INFO_FORMAT = " %.4s (%.4s)"

local onlineTime = 0;
local timer = 0;
local doScan, loaded;

local microButtons = {
 MainMenuMicroButton,
 CharacterMicroButton,
 SpellbookMicroButton,
 TalentMicroButton,
 AchievementMicroButton,
 QuestLogMicroButton,
 GuildMicroButton,
 LFDMicroButton,
 CollectionsMicroButton,
 EJMicroButton,
 StoreMicroButton,
 MainMenuBarBackpackButton,
 CharacterBag0Slot,
 CharacterBag1Slot,
 CharacterBag2Slot,
 CharacterBag3Slot,
};

if MICRO_BUTTONS and CopyTable then
 wipe(microButtons)
 microButtons = CopyTable(MICRO_BUTTONS)
end

--[[Check if we need special handling for MicroButtonPortrait, GuildMicroButtonTabard
Those are the two that have separate events modifying their alpha.
Might need to also hook GuildMicroButton_UpdateTabard() or just add it to the frame list.
]]--

local ilevelSlots = {
 (GetInventorySlotInfo("HeadSlot")),
 (GetInventorySlotInfo("NeckSlot")),
 (GetInventorySlotInfo("ShoulderSlot")),
 (GetInventorySlotInfo("BackSlot")),
 (GetInventorySlotInfo("ChestSlot")),
 (GetInventorySlotInfo("WristSlot")),
 (GetInventorySlotInfo("HandsSlot")),
 (GetInventorySlotInfo("WaistSlot")),
 (GetInventorySlotInfo("LegsSlot")),
 (GetInventorySlotInfo("FeetSlot")),
 (GetInventorySlotInfo("Finger0Slot")),
 (GetInventorySlotInfo("Finger1Slot")),
 (GetInventorySlotInfo("Trinket0Slot")),
 (GetInventorySlotInfo("Trinket1Slot")),
 (GetInventorySlotInfo("MainHandSlot")),
 (GetInventorySlotInfo("SecondaryHandSlot")),
}

function TinyMainbarInfo_Setup(enabled)
  TinyMainbarInfo_Enabled = enabled;
  if TinyMainbarInfo_Enabled then
  for i,v in ipairs(microButtons) do
   local btn = _G[v]
   if btn then btn:SetAlpha(0) end
  end
    MicroButtonAndBagsBar.MicroBagBar:SetAlpha(0.6);
    MicroButtonAndBagsBar.MicroBagBar:SetAlpha(0.6);
    TinyMainbarInfoFrame:Show();
  else
  for i,v in ipairs(microButtons) do
   local btn = _G[v]
   if btn then btn:SetAlpha(1) end
  end
    MicroButtonAndBagsBar.MicroBagBar:SetAlpha(1);
    MicroButtonAndBagsBar.MicroBagBar:SetAlpha(1);
    TinyMainbarInfoFrame:Hide();
  end
end

local function TinyMainbarInfo_UpdateMicroButtons()
  if TinyMainbarInfo_Enabled then
    TinyMainbarInfo_Setup(true);
  else
    TinyMainbarInfo_Setup(false);
  end
end

local function TinyMainbarInfo_dura()
 local minDura = 100
 for index, value in pairs(INVENTORY_ALERT_STATUS_SLOTS) do
  local cur, maxim = GetInventoryItemDurability(index)
  if cur then
   percent = (cur/maxim) * 100
   minDura = percent < minDura and percent or minDura
  end
 end
 if minDura<25 then
  FORMAT_DURABILITY = "|TInterface\\Icons\\Trade_BlackSmithing:0|t "..RED_FONT_COLOR_CODE.."%d%%"..FONT_COLOR_CODE_CLOSE
 elseif minDura<65 then
  FORMAT_DURABILITY = "|TInterface\\Icons\\Trade_BlackSmithing:0|t "..YELLOW_FONT_COLOR_CODE.."%d%%"..FONT_COLOR_CODE_CLOSE
 else
  FORMAT_DURABILITY = "|TInterface\\Icons\\Trade_BlackSmithing:0|t "..GREEN_FONT_COLOR_CODE.."%d%%"..FONT_COLOR_CODE_CLOSE
 end
 return format(FORMAT_DURABILITY,minDura)
end

local quality = {}
local function TinyMainBarInfo_iLvl()
 local avgilvl, oldilvl
 wipe(quality)
 local count, total = 0,0
 for i,v in ipairs(ilevelSlots) do
  local id = GetInventoryItemID("player",v)
  if id then
   local n,_,q,ilvl = GetItemInfo(id)
   if n then
    total = total + ilvl
    count = count + 1
    quality[q] = quality[q] and quality[q]+1 or 1
   end
  end
 end
 if total > 0 and count > 0 then
  oldilvl = total/count
 end
 local maj, num = 0,0
 if next(quality) then
  for k,v in pairs(quality) do
   num = v>num and v or num
  end
  for k,v in pairs(quality) do
   if v == num then
    maj = k
    break
   end
  end
 end
 if maj then
  FORMAT_ILEVEL_COLOR = "|c"..select(4,GetItemQualityColor(maj)).."%d"..FONT_COLOR_CODE_CLOSE
 end
 if GetAverageItemLevel then
  local avgilvleq
  avgilvl, avgilvleq = GetAverageItemLevel()
  if avgilvleq then oldilvl = avgilvleq end
 end
 if avgilvl and oldilvl then
  return format(FORMAT_ILEVEL.." ("..FORMAT_ILEVEL_COLOR..")",avgilvl,oldilvl)
 elseif avgilvl then
  return format(FORMAT_ILEVEL,avgilvl)
 elseif oldilvl then
  return format(FORMAT_ILEVEL_COLOR,oldilvl)
 else
  return "?"
 end
end

local function TinyMainbarInfo_modf(num)
  return math.floor(num), num - math.floor(num);
end

local function TinyMainbarInfo_OnLoad(self)
  hooksecurefunc("UpdateMicroButtons",TinyMainbarInfo_UpdateMicroButtons);
  --hooksecurefunc("GuildMicroButton_UpdateTabard",TinyMainbarInfo_UpdateMicroButtons); -- check if needed

  self:RegisterEvent("ZONE_CHANGED_NEW_AREA")
  self:RegisterEvent("PLAYER_ENTERING_WORLD")
  self:RegisterEvent("PLAYER_MONEY")
  self:RegisterEvent("UPDATE_INVENTORY_DURABILITY")
  self:RegisterEvent("UPDATE_INVENTORY_ALERTS")
  -- no longer valid as of BFA -- self:RegisterEvent("PLAYER_AVG_ITEM_LEVEL_READY")
  self:RegisterEvent("PLAYER_EQUIPMENT_CHANGED")
  self:RegisterEvent("PLAYER_FLAGS_CHANGED")

  TinyMainbarInfo_Setup(true);
 for i,v in ipairs(microButtons) do
  local btn = _G[v]
  if btn then
   btn:HookScript("OnEnter", function(self) TinyMainbarInfo_Setup(false) end)
   btn:HookScript("OnLeave", function(self) TinyMainbarInfo_Setup(true) end)
  end
 end
end

local function TinyMainbarInfo_OnEvent(self, event, ...)
 if event == "PLAYER_ENTERING_WORLD" then
  -- money, durability, ilvl
  self.moneyText:SetText(GetCoinTextureString(GetMoney(),10))
  self.duraText:SetText(TinyMainbarInfo_dura())
  self.ilvlText:SetText(TinyMainBarInfo_iLvl())
  self.onlineIcon:SetText(UnitIsAFK("player") and "|TInterface\\FriendsFrame\\StatusIcon-Away:0|t" or UnitIsDND("player") and "|TInterface\\FriendsFrame\\StatusIcon-DnD:0|t" or "|TInterface\\FriendsFrame\\StatusIcon-Online:0|t")
  self:RegisterEvent("BAG_UPDATE")
 elseif event == "UPDATE_INVENTORY_DURABILITY" or event == "UPDATE_INVENTORY_ALERTS" then
  -- durability
  self.duraText:SetText(TinyMainbarInfo_dura())
 elseif event == "PLAYER_AVG_ITEM_LEVEL_READY" or event == "PLAYER_EQUIPMENT_CHANGED" or event == "BAG_UPDATE" then
  -- average ilvl
  doScan = GetTime() -- done in OnUpdate2 when there's 0.5 sec from last request passed.
 elseif event == "PLAYER_MONEY" then
  -- money
  self.moneyText:SetText(GetCoinTextureString(GetMoney(),10))
 elseif event == "PLAYER_FLAGS_CHANGED" then
  -- online time icon (on,away,dnd)
  self.onlineIcon:SetText(UnitIsAFK("player") and "|TInterface\\FriendsFrame\\StatusIcon-Away:0|t" or UnitIsDND("player") and "|TInterface\\FriendsFrame\\StatusIcon-DnD:0|t" or "|TInterface\\FriendsFrame\\StatusIcon-Online:0|t")
  -- removed fro BFA-- elseif event == "ZONE_CHANGED_NEW_AREA" then
  --
 end
end

local function TinyMainbarInfo_OnUpdate(self, elapsed)
  onlineTime = onlineTime + elapsed;
  timer = timer + elapsed;
end

local function TinyMainbarInfo_OnUpdate2(self, elapsed)
 if doScan and GetTime()>(doScan+0.5) then
  self.ilvlText:SetText(TinyMainBarInfo_iLvl())
   doScan = nil
  end
  if timer > 1 then
    isInstance, instanceType = IsInInstance()
    if (IsInInstance()) then
       self.coordText:SetText(string.format(FORMAT_COORDS, 0, 0));
    else
       local mapID = C_Map.GetBestMapForUnit("player")
       if mapID then
          local  mapPos = C_Map.GetPlayerMapPosition(mapID, "player")
          if mapPos then
             x, y = mapPos:GetXY()
          end
       else
          x = 0
          y = 0
       end
       if x == 0 or y == 0 or x == nil or y == nil then
          self.coordText:SetText(string.format(FORMAT_COORDS, 0, 0));
       else
          self.coordText:SetText(string.format(FORMAT_COORDS, x * 100, y * 100));
       end
    end
    -- Update network flow
    local kbin, kbout, mlatency, wlatency = GetNetStats();
    self.netText:SetText(string.format(FORMAT_NETSTATS, kbin + kbout));

    --# world latency
    if mlatency >= 600 then
      FORMAT_LAG = RED_FONT_COLOR_CODE.."%d"..FONT_COLOR_CODE_CLOSE;
    elseif mlatency >= 300 then
      FORMAT_LAG = YELLOW_FONT_COLOR_CODE.."%d"..FONT_COLOR_CODE_CLOSE;
    else
      FORMAT_LAG = GREEN_FONT_COLOR_CODE.."%d"..FONT_COLOR_CODE_CLOSE;
    end
    --# home latency
    if wlatency >= 600 then
      FORMAT_LAG = FORMAT_LAG.." ("..RED_FONT_COLOR_CODE.."%d"..FONT_COLOR_CODE_CLOSE..") ms";
    elseif wlatency >= 300 then
      FORMAT_LAG = FORMAT_LAG.." ("..YELLOW_FONT_COLOR_CODE.."%d"..FONT_COLOR_CODE_CLOSE..") ms";
    else
      FORMAT_LAG = FORMAT_LAG.." ("..GREEN_FONT_COLOR_CODE.."%d"..FONT_COLOR_CODE_CLOSE..") ms";
    end
    self.latText:SetText(string.format(FORMAT_LAG, wlatency, mlatency));

    if (IsInGuild()) then
       GuildRoster()
       -- Guild members online if in Guild
       local numTotal, numOnlineMaxLevel, numOnline = GetNumGuildMembers();
       self.onlineText:SetText(string.format(GUILD_INFO_FORMAT, numOnline, numTotal));
    else
    -- Update time played this session
       local hours, frac = TinyMainbarInfo_modf(onlineTime / 60 / 60);
       local minutes, frac = TinyMainbarInfo_modf(frac * 60);
       local seconds =   TinyMainbarInfo_modf(frac * 60);
       self.onlineText:SetText(string.format(FORMAT_TIME_ONLINE, hours, minutes, seconds));
    end

    -- Update interface memory usage
    -- Updated to only grep Additional Addon Memory Usage exclude the default Blizzard Addons.
    local meg = 0
    UpdateAddOnMemoryUsage()
    for i = 1, GetNumAddOns() do
      meg = meg + (GetAddOnMemoryUsage(i)/1024)
    end
    self.memText:SetText(string.format(FORMAT_MEMORY_USAGE, meg));

    -- Update fps
    local fps = GetFramerate()
    if fps < 15 then
      FORMAT_FPS = RED_FONT_COLOR_CODE.."%.1f FPS"..FONT_COLOR_CODE_CLOSE
    elseif fps < 30 then
      FORMAT_FPS = YELLOW_FONT_COLOR_CODE.."%.1f FPS"..FONT_COLOR_CODE_CLOSE
    else
      FORMAT_FPS = "%.1f FPS"
    end
    self.fpsText:SetText(string.format(FORMAT_FPS, fps));

    timer = 0;
  end
end

do
 local timeframe = CreateFrame("Frame")
 timeframe:SetScript("OnUpdate", TinyMainbarInfo_OnUpdate)

 local f = CreateFrame("Frame","TinyMainbarInfoFrame",MicroButtonAndBagsBar)
 f:SetFrameLevel(f:GetParent():GetFrameLevel()+1)
 f:SetScript("OnEvent", TinyMainbarInfo_OnEvent)
 f:SetScript("OnUpdate", TinyMainbarInfo_OnUpdate2)

 local onlineIcon = f:CreateFontString(nil,"OVERLAY") -- left column
 local onlineText = f:CreateFontString(nil,"OVERLAY")
 -- first # is left and right second is up and down
 onlineIcon:SetPoint("TOPLEFT",MicroButtonAndBagsBar,"TOPLEFT", 10,-50 )
 onlineText:SetPoint("TOPLEFT",onlineIcon,"TOPRIGHT",0,0)
 f.onlineText = onlineText
 f.onlineText:SetFontObject("GameFontNormalSmall")
 f.onlineText:SetTextColor(1,1,1)
 f.onlineIcon = onlineIcon
 f.onlineIcon:SetFontObject("GameFontNormalSmall")
 f.onlineIcon:SetTextColor(1,1,1)

 local coordText = f:CreateFontString(nil,"OVERLAY")
 coordText:SetPoint("TOPLEFT",onlineIcon,"BOTTOMLEFT",0,-3)
 f.coordText = coordText
 f.coordText:SetFontObject("GameFontNormalSmall") -- fontsize 10
 f.coordText:SetTextColor(1,1,1)

 local latText = f:CreateFontString(nil,"OVERLAY")
 latText:SetPoint("TOPLEFT",coordText,"BOTTOMLEFT",0,-3)
 f.latText = latText
 f.latText:SetFontObject("GameFontNormalSmall")
 f.latText:SetTextColor(1,1,1)

 local moneyText = f:CreateFontString(nil,"OVERLAY") -- middle column
 moneyText:SetPoint("TOPLEFT",onlineIcon,"TOPRIGHT",75,0)
 f.moneyText = moneyText
 f.moneyText:SetFontObject("GameFontNormalSmall")
 f.moneyText:SetTextColor(1,1,1)

 local duraText = f:CreateFontString(nil,"OVERLAY")
 duraText:SetPoint("TOP",moneyText,"BOTTOM",-10,-3)
 f.duraText = duraText
 f.duraText:SetFontObject("GameFontNormalSmall")
 f.duraText:SetTextColor(1,1,1)

 local ilvlText = f:CreateFontString(nil,"OVERLAY")
 ilvlText:SetPoint("TOP",duraText,"BOTTOM",0,-3)
 f.ilvlText = ilvlText
 f.ilvlText:SetFontObject("GameFontNormalSmall")
 f.ilvlText:SetTextColor(1,1,1)

 local fpsText = f:CreateFontString(nil,"OVERLAY") -- right column
 fpsText:SetPoint("TOPLEFT",moneyText,"TOPRIGHT",45,0)
 f.fpsText = fpsText
 f.fpsText:SetFontObject("GameFontNormalSmall")
 f.fpsText:SetTextColor(1,1,1)

 local memText = f:CreateFontString(nil,"OVERLAY")
 memText:SetPoint("TOPRIGHT",fpsText,"BOTTOMRIGHT",0,-3)
 f.memText = memText
 f.memText:SetFontObject("GameFontNormalSmall")
 f.memText:SetTextColor(1,1,1)

 local netText = f:CreateFontString(nil,"OVERLAY")
 netText:SetPoint("TOPRIGHT",memText,"BOTTOMRIGHT",0,-3)
 f.netText = netText
 f.netText:SetFontObject("GameFontNormalSmall")
 f.netText:SetTextColor(1,1,1)

 TinyMainbarInfo_OnLoad(f)
end
--EOF
